#ifndef _SOURCEBASE_BACKEND_H
#define _SOURCEBASE_BACKEND_H

#include <glib.h>

#ifdef __cplusplus
extern "C" {
#endif

int init_db (const char *dir);
int add_parser (const char *parser_name, const char *file_name, const char *extns, int attrs);
/**
 * \fn close_db
 * \brief Close the SQLite database. All active transactions are COMMITTED.
 * \return 0
 */
int close_db (void);

int put_xref (int type,int scope_type,int scope_lev,char *fnc_cls,
    char *fnc,char *fnc_arg_types,char *scope,char *what,char *arg_types,
    char *file,int lineno,int acc);
/**
 * \fn find_file_in_db
 * \brief Search for a file in the project database
 * \param file_name File name to search for (Relative/Absolute path)
 * \param path OUTPUT: Absolute path of the file. Must be preallocated and MAX_PATH long.
 * \return integer
 * 	- 0 on success
 * 	- -1 on error
 */
int find_file_in_db (const char *file_name,char *path);

/**
 * Creates a hash table of all the parser and their parsed extensions.
 * Parsed extensions are the key (gchar *) and parser ids are the data (gint *)
 * All the info (parser ids and extensions) are taken from PARSER and PARSER_EXTNS tables
 * @return New allocated GHashTable. Free it when done.
 */
GHashTable *get_parsed_extns_from_db (void);
GHashTable *get_project_files_from_db (void);
GHashTable *get_parsers_from_db (void);

#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif /* _SOURCEBASE_BACKEND_H */
