/*
 * sourcebase-parser.h
 * Copyright (C) 1998 Cygnus Solutions
 * Copyright (C) 2003 Biswapesh Chatopadhyay
 */

/** @file
 * This file contains headers for a set of useful functions
 * which can be used by the parsers.
 */

#ifndef _SOURCEBASE_PARSER_H
#define _SOURCEBASE_PARSER_H

#include <stdio.h>

#include "sourcebase.h"

#ifdef __cplusplus
extern "C" {
#endif

typedef int (*sb_lexer_fn_t) (void);
typedef void (*sb_lexer_reset_fn_t) (void);

/**
 * A parser can simply call this function to do most of the routine work.
 */
int sb_parse_main(const char *file_name, const char *parser, FILE ** lexstream
  , sb_lexer_fn_t lexer_fn, sb_lexer_reset_fn_t reset_fn);

/*
 * Line/column manipulators; this library looks after keeping count of them.
 */
void sb_set_column(long column);
void sb_reset_column();
void sb_advance_column(int num);

void sb_set_line(long line);
void sb_reset_line();
void sb_advance_line();

/*
 * Functions for saving at most one line/column number.  The *pop() 
 * functions return -1 if too many pops are done.
 */
void sb_push_line();
long sb_pop_line();

void sb_push_column();
long sb_pop_column();

/*
 * Count the number of characters in a null-terminated buffer.  Increment the
 * internal line/column counters accordingly.
 */ 
void sb_count_chars(char *buf, int length);

/*
 * Functions to get the current line/column numbers.
 */
long sb_column();
long sb_line();

/*
 * Return the name of the currently parsed source file. 
 */
char *sb_current_file();

/*
 * Use GNU flex's YYINPUT macro to call this function and make your
 * scanner i18n-aware. (@todo Make this work with glib)
 */
int sb_encoded_input(char *buf, int max_size);

/*
 * This function should be called at the start of each new file being lexed.
 */
void sb_reset_encoding();

#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif /* _SOURCEBASE_PARSER_H */
