/*
 * sourcebase.h
 * Copyright (C) Biswapesh Chattopadhyay 2003
 * This file is the main high-level interface to sourcebase.
 */
 
#ifndef _SOURCEBASE_UTILS_H
#define _SOURCEBASE_UTILS_H

#include <glib.h>
#ifdef __cplusplus
extern "C" {
#endif

#ifdef DEBUG
#define g_debug_message(F, args...) g_message(F, ## args)
#else
#define g_debug_message(F, args...)
#endif

/**
 * Retrieves the file extension.
 * Returns the file extension if file_name contains at least one dot
 * or the entire filename if there are no dots.
 * @param file_name Name of the file
 * @return New allocated pointer to file extension. Free it when done.
 */
gchar *get_file_extension (const gchar *file_name);

/**
 * Scan (maybe recursively) a directory and return a list of files/directories.
 * Each element in the list is a SBDirEntry * instance;
 * @param root_dir Starting point
 * @param recurse Wheter to recursively scan all the directories under the root
 * @return A list of all the files found, or NULL if some error occurred
 */
GList *traverse_path (gchar *root_dir, gboolean recurse);

#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif /* _SOURCEBASE_UTILS_H */
