#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include "sourcebase.h"
#include "utils.h"

static gchar delimiter[] = ".";

gchar *get_file_extension (const gchar *file_name)	{
	gint i;
	gchar *basename = g_path_get_basename (file_name);

	gchar **splitarray = g_strsplit (basename, delimiter, 0);
	for (i=0; splitarray[i]; i++);
	gchar *extension = g_strdup (splitarray[--i]);
	// g_message ("Extension of %s is %s", file_name, extension);
	g_free (basename);
	g_strfreev (splitarray);
	return (extension);
}

GList *traverse_path (gchar *root_dir, gboolean recurse)	{
	g_return_val_if_fail (root_dir, NULL);
	GDir *directory = NULL;
	GList *list = NULL;
	gchar *fullpath = NULL;
	G_CONST_RETURN gchar *dir_entry = NULL;
	SBDirEntry *Entry;
	DBFilesTableElem *FileElem;
	DBDirectoriesTableElem *DirElem;
	
	if (!g_file_test (root_dir, G_FILE_TEST_IS_DIR))	{
		g_warning ("Path %s is not a directory!", root_dir);
		return list;
	}
	directory = g_dir_open (root_dir, 0, NULL);
	if (!directory)	{
		g_warning ("Cannot open path %s!", root_dir);
		return list;
	}

	while (TRUE)	{
		dir_entry = g_dir_read_name (directory);
		if (!dir_entry)
			break;
		Entry = g_new0 (SBDirEntry, 1);
		fullpath = g_build_filename (root_dir, dir_entry);
		if (g_file_test (fullpath, G_FILE_TEST_IS_DIR) && recurse)	{
			DirElem = g_new0 (DBDirectoriesTableElem, 1);
			DirElem->dir_path = fullpath;
			// TODO: decide whether is source or include
			DirElem->dir_type = SB_DIR_BOTH;
			Entry->EntryType = SB_DIRENTRY_DIRECTORY;
			Entry->DirElem = DirElem;
			list = g_list_append (list, (gpointer) Entry);
			list = g_list_concat (list, traverse_path (fullpath, recurse));
		}	else if (g_file_test (fullpath, G_FILE_TEST_IS_REGULAR))	{
			FileElem = g_new0 (DBFilesTableElem, 1);
			FileElem->file_path = fullpath;
			FileElem->file_name = g_path_get_basename (fullpath);
			FileElem->file_dir = g_path_get_dirname (fullpath);
			Entry->EntryType = SB_DIRENTRY_FILE;
			Entry->FileElem = FileElem;
			list = g_list_append (list, (gpointer) Entry);
		}	else	{
			//We got this file entry but is not a dir nor a regular file.
			//Perhaps a symlink, just skip it.
			continue;
		}
	}
	g_dir_close (directory);
	return g_list_first (list);
}
